@@ -100,7 +100,7 @@ maze_solve <- function(
 
   class(result) <- c("maze_solve", class(result))
   if (!quiet) print(result)
-  return(invisible(result))
+  invisible(result)
 }
 
 #' @rdname maze_solve
@@ -134,61 +134,54 @@ maze_solve_recursive <- function(
     timeout = 10,
     path_coords = data.frame(row = integer(0), col = integer(0)),
     prev_direction = NULL) {
-  # When solution found or timeout reached, return results
+  # Check for timeout or goal reached
   toci <- toc("maze_solve_timeout", quiet = TRUE)
   timeout_reached <- any(toci$toc - toci$tic > timeout)
-  if (any(c(identical(current, end), timeout_reached))) {
-    if (timeout_reached) {
-      return(FALSE)
-    }
-    return(list(maze = maze, path_coords = path_coords))
-  }
 
-  # Mark the current cell as part of the solution path
-  row <- current[1]
-  col <- current[2]
-  maze[row, col] <- "X"
+  if (timeout_reached) {
+    FALSE
+  } else if (identical(current, end)) {
+    list(maze = maze, path_coords = path_coords)
+  } else {
+    row <- current[1]
+    col <- current[2]
+    maze[row, col] <- "X"
+    path_coords <- rbind(path_coords, c(row, col))
 
-  # Update path coordinates
-  path_coords <- rbind(path_coords, c(row, col))
+    target <- if (aim) end else c(row, col)
+    positions <- rank_positions(row, col, target[1], target[2], diagonal)
+    if (random) positions <- positions[sample(nrow(positions)), ]
 
-  # Rank next positions based on minimum distance to goal
-  temp <- if (aim) end else c(row, col)
-  positions <- rank_positions(row, col, temp[1], temp[2], diagonal)
-  if (random) positions <- positions[sample(seq_len(nrow(positions))), ]
-
-  # Ensure that the direction it came from is the first move if inertia is TRUE
-  if (!is.null(prev_direction) & isTRUE(inertia)) {
-    first_point <- linear_extrapolation(prev_direction[1], prev_direction[2], row, col)
-    if (all(!is.na(first_point))) {
-      skip <- which(positions$x == first_point[1] & positions$y == first_point[2])
-      if (length(skip) > 0) {
-        positions <- rbind(first_point, positions[-skip, -3])
+    if (!is.null(prev_direction) && isTRUE(inertia)) {
+      first_point <- linear_extrapolation(prev_direction[1], prev_direction[2], row, col)
+      if (all(!is.na(first_point))) {
+        skip <- which(positions$x == first_point[1] & positions$y == first_point[2])
+        if (length(skip) > 0) {
+          positions <- rbind(first_point, positions[-skip, -3])
+        }
       }
     }
-  }
 
-  for (i in seq_len(nrow(positions))) {
-    next_row <- positions$x[i]
-    next_col <- positions$y[i]
+    results <- lapply(seq_len(nrow(positions)), function(i) {
+      next_row <- positions$x[i]
+      next_col <- positions$y[i]
 
-    # Check if the next cell is within bounds and is an open path
-    if (next_row > 0 && next_row <= nrow(maze) &&
-      next_col > 0 && next_col <= ncol(maze) &&
-      maze[next_row, next_col] == 0) {
-      # Recursively explore the next cell
-      nexti <- c(next_row, next_col)
-      result <- maze_solve_recursive(
-        maze, nexti, end, aim, inertia, diagonal, random,
-        timeout, path_coords,
-        prev_direction = c(row, col)
-      )
-      if (!is.logical(result)) {
-        return(result)
+      if (next_row > 0 && next_row <= nrow(maze) &&
+        next_col > 0 && next_col <= ncol(maze) &&
+        maze[next_row, next_col] == 0) {
+        maze_solve_recursive(
+          maze, c(next_row, next_col), end,
+          aim, inertia, diagonal, random,
+          timeout, path_coords,
+          prev_direction = c(row, col)
+        )
+      } else {
+        FALSE
       }
-    }
+    })
+    match_found <- Filter(function(res) !is.logical(res), results)
+    if (length(match_found) > 0) match_found[[1]] else FALSE
   }
-  return(FALSE) # No solution found from this point
 }
 
 #' @rdname maze_solve
@@ -235,7 +228,7 @@ maze_gridsearch <- function(
     arrange(.data$steps_counter, .data$turns_counter) %>%
     select(.data$id, contains("counter"), everything(), .data$start, .data$end) %>%
     data.frame()
-  return(list(solutions = results, results = counters))
+  list(solutions = results, results = counters)
 }
 
 # Function to calculate the number of direction changes
@@ -297,7 +290,7 @@ rank_positions <- function(x1, y1, x2, y2, diagonal = TRUE) {
   }
   positions$d <- sqrt((positions$x - x2)^2 + (positions$y - y2)^2)
   ranked_positions <- positions[order(positions$d), ]
-  return(ranked_positions)
+  ranked_positions
 }
 
 # Function to perform linear extrapolation and return the next integer point
