@@ -27,6 +27,7 @@
 #'
 #' @family Machine Learning
 #' @inheritParams h2o::h2o.automl
+#' @inheritParams get_mp3
 #' @param df Dataframe. Dataframe containing all your data, including
 #' the dependent variable labeled as \code{'tag'}. If you want to define
 #' which variable should be used instead, use the \code{y} parameter.
@@ -75,7 +76,6 @@
 #' When both are defined, only \code{include_algos} will be valid.
 #' @param plots Boolean. Create plots objects?
 #' @param alarm Boolean. Ping (sound) when done. Requires \code{beepr}.
-#' @param quiet Boolean. Quiet all messages, warnings, recommendations?
 #' @param print Boolean. Print summary when process ends?
 #' @param save Boolean. Do you wish to save/export results into your
 #' working directory?
@@ -266,7 +266,7 @@ h2o_automl <- function(df, y = "tag",
   }
 
   attr(results, "type") <- "h2o_automl"
-  return(results)
+  results
 }
 
 #' @rdname h2o_automl
@@ -599,8 +599,7 @@ h2o_results <- function(h2o_object, test, train, y = "tag", which = 1,
 
   attr(results, "type") <- "h2o_automl"
   class(results) <- c("h2o_automl", class(results))
-
-  return(results)
+  results
 }
 
 .get_scores <- function(predictions,
@@ -641,8 +640,7 @@ h2o_results <- function(h2o_object, test, train, y = "tag", which = 1,
   } else {
     scores <- data.frame(score = as.vector(scores))
   }
-  ret <- list(scores = scores, multis = multis)
-  return(ret)
+  list(scores = scores, multis = multis)
 }
 
 
@@ -687,7 +685,7 @@ h2o_selectmodel <- function(results, which_model = 1, quiet = FALSE, ...) {
   )
 
   if (!quiet) print(output)
-  return(output)
+  output
 }
 
 
@@ -886,15 +884,13 @@ msplit <- function(df, size = 0.7, seed = 0, print = TRUE) {
 
   if (print == TRUE) print(summary)
 
-  sets <- list(
+  list(
     train = train,
     test = test,
     summary = summary,
     split_size = size,
     train_index = ind
   )
-
-  return(sets)
 }
 
 
@@ -904,13 +900,13 @@ msplit <- function(df, size = 0.7, seed = 0, print = TRUE) {
 #' This function detects or forces the target value when predicting
 #' a categorical binary model. This is an auxiliary function.
 #'
+#' @inheritParams get_mp3
 #' @param tag Vector. Real known label
 #' @param score Vector. Predicted value or model's result
 #' @param target Value. Which is your target positive value? If
 #' set to 'auto', the target with largest mean(score) will be
 #' selected. Change the value to overwrite. Only used when binary
 #' categorical model.
-#' @param quiet Boolean. Do not show message for auto target?
 #' @return List. Contains original data.frame \code{df} and
 #' \code{which} with the target variable.
 #' @export
@@ -942,8 +938,7 @@ target_set <- function(tag, score, target = "auto", quiet = FALSE) {
   if (!quiet) message(paste("Target value:", target))
   # If the forced target value is the "lower scores" value, invert scores
   if (auto != target) df$score <- df$score * (-1) + 1
-  ret <- list(df = df, which = target)
-  return(ret)
+  list(df = df, which = target)
 }
 
 
@@ -967,12 +962,12 @@ iter_seeds <- function(df, y, tries = 10, ...) {
     seeds <- arrange(seeds, desc(2))
     statusbar(i, tries, seeds[1, 1])
   }
-  return(seeds)
+  seeds
 }
 
 .quiet_h2o <- function(..., quiet = TRUE) {
   if (quiet) on.exit(h2o.no_progress())
   x <- eval(...)
   h2o.show_progress()
-  return(x)
+  x
 }
