@@ -219,7 +219,7 @@ model_metrics <- function(tag, score, multis = NA,
     metrics$dictionary <- NULL
   }
 
-  return(metrics)
+  metrics
 }
 
 
@@ -260,36 +260,35 @@ conf_mat <- function(tag, score, thresh = 0.5,
   df <- data.frame(tag, score)
   if (!diagonal) df <- filter(df, .data$tag != .data$score)
   if (plot) {
-    return(mplot_conf(df$tag, df$score, thresh = thresh))
-  }
-
-  # About tags
-  labels <- df %>%
-    group_by(.data$tag, .drop = FALSE) %>%
-    tally(wt = NULL) %>%
-    arrange(desc(.data$n)) %>%
-    .$tag
-  df <- df %>% mutate(tag = factor(.data$tag, levels = unique(.data$tag)))
-
-  # About scores
-  if (is.numeric(df$score) && length(unique(tag)) == 2) {
-    check_opts(sense, c("<", "<=", ">=", ">"))
-    s <- do.call(sense, list(df$score, thresh))
-    df <- mutate(df, pred = ifelse(s, as.character(labels[1]), as.character(labels[2])))
+    mplot_conf(df$tag, df$score, thresh = thresh)
   } else {
-    df <- mutate(df, pred = .data$score)
+    # About tags
+    labels <- df %>%
+      group_by(.data$tag, .drop = FALSE) %>%
+      tally(wt = NULL) %>%
+      arrange(desc(.data$n)) %>%
+      .$tag
+    df <- df %>% mutate(tag = factor(.data$tag, levels = unique(.data$tag)))
+
+    # About scores
+    if (is.numeric(df$score) && length(unique(tag)) == 2) {
+      check_opts(sense, c("<", "<=", ">=", ">"))
+      s <- do.call(sense, list(df$score, thresh))
+      df <- mutate(df, pred = ifelse(s, as.character(labels[1]), as.character(labels[2])))
+    } else {
+      df <- mutate(df, pred = .data$score)
+    }
+
+    # Confusion Matrix
+    ret <- df %>%
+      rename("Real" = .data$tag, "Pred" = .data$pred) %>%
+      crosstab(.data$Real, .data$Pred, total = FALSE)
+    myRows <- as.character(unlist(ret[, 1]))
+    myCols <- colnames(ret[, -1])
+    ret <- ret[, c("Real x Pred", myCols[order(match(myCols, myRows))])]
+    ret[is.na(ret)] <- 0
+    as_tibble(ret)
   }
-
-  # Confusion Matrix
-  ret <- df %>%
-    rename("Real" = .data$tag, "Pred" = .data$pred) %>%
-    crosstab(.data$Real, .data$Pred, total = FALSE)
-  myRows <- as.character(unlist(ret[, 1]))
-  myCols <- colnames(ret[, -1])
-  ret <- ret[, c("Real x Pred", myCols[order(match(myCols, myRows))])]
-  ret[is.na(ret)] <- 0
-
-  return(as_tibble(ret))
 }
 
 
@@ -375,9 +374,10 @@ gain_lift <- function(tag, score, target = "auto", splits = 10,
       tag, score,
       target = which, splits = splits
     )
-    return(plots)
+    plots
+  } else {
+    gains
   }
-  return(gains)
 }
 
 
@@ -463,7 +463,7 @@ ROC <- function(tag, score, multis = NA) {
   if (!is.na(multis)[1]) {
     ret[["rocs"]] <- rocs
   }
-  return(ret)
+  ret
 }
 
 
@@ -602,8 +602,7 @@ loglossBinary <- function(tag, score, eps = 0.001) {
 
   score <- pmax(pmin(score, 1 - eps), eps)
   output <- -mean(tag * log(score) + (1 - tag) * log(1 - score))
-
-  return(output)
+  output
 }
 
 .square_table <- function(x, y) {
